@@ -36,6 +36,7 @@ class KCalendarCore::EventPrivate : public IncidencePrivate
 public:
     EventPrivate() = default;
     explicit EventPrivate(const Incidence &);
+    bool validStatus(Incidence::Status) override;
 
     QDateTime mDtEnd;
     Event::Transparency mTransparency = Event::Opaque;
@@ -49,6 +50,16 @@ EventPrivate::EventPrivate(const Incidence &other)
     : IncidencePrivate(other)
 {
 }
+
+bool EventPrivate::validStatus(Incidence::Status status)
+{
+    constexpr unsigned validSet
+        = 1u << Incidence::StatusNone
+        | 1u << Incidence::StatusTentative
+        | 1u << Incidence::StatusConfirmed
+        | 1u << Incidence::StatusCanceled;
+    return validSet & (1u << status);
+}
 //@endcond
 
 Event::Event()
@@ -94,8 +105,7 @@ bool Event::equals(const IncidenceBase &event) const
     } else {
         // If they weren't the same type IncidenceBase::equals would had returned false already
         const Event *e = static_cast<const Event *>(&event);
-        return ((dtEnd() == e->dtEnd() && dtEnd().timeSpec() == e->dtEnd().timeSpec()) || (!dtEnd().isValid() && !e->dtEnd().isValid()))
-            && transparency() == e->transparency();
+        return identical(dtEnd(), e->dtEnd()) && transparency() == e->transparency();
     }
 }
 
@@ -123,7 +133,7 @@ void Event::setDtEnd(const QDateTime &dtEnd)
     }
 
     Q_D(Event);
-    if (d->mDtEnd != dtEnd || d->mDtEnd.timeSpec() != dtEnd.timeSpec() || hasDuration() == dtEnd.isValid()) {
+    if (!identical(d->mDtEnd, dtEnd) || hasDuration() == dtEnd.isValid()) {
         update();
         d->mDtEnd = dtEnd;
         d->mMultiDayValid = false;
