@@ -104,6 +104,7 @@ class KCALENDARCORE_EXPORT IncidenceBase : public CustomProperties
     Q_PROPERTY(bool allDay READ allDay WRITE setAllDay)
     Q_PROPERTY(KCalendarCore::Person organizer READ organizer WRITE setOrganizer)
     Q_PROPERTY(QVariantList attendees READ attendeesVariant)
+    Q_PROPERTY(QUrl url READ url WRITE setUrl)
 
 public:
     /**
@@ -778,6 +779,18 @@ private:
     friend KCALENDARCORE_EXPORT QDataStream &operator>>(QDataStream &stream, KCalendarCore::IncidenceBase::Ptr &);
 };
 
+/**
+ * Compare two QDateTimes for extended equality.
+ *
+ * QDateTime::operator==() in Qt 5.12 returns true if its operands represent
+ * the same instant in time, regardless of their time zones or TimeSpecs (and
+ * contrary to the documentation).  This function returns true if and only if
+ * their times, time zones, and TimeSpecs are equal, or both are invalid().
+ *
+ * @since 5.93
+ */
+KCALENDARCORE_EXPORT bool identical(QDateTime, QDateTime);
+
 /**
  * Incidence serializer.
  *
