@@ -15,13 +15,14 @@
 
 class QDataStream;
 
-namespace KCalendarCore {
-
+namespace KCalendarCore
+{
 /**
  * Helpers to retain backwards compatibility of binary serialization.
  */
 void serializeQDateTimeAsKDateTime(QDataStream &out, const QDateTime &dt);
 KCALENDARCORE_EXPORT void deserializeKDateTimeAsQDateTime(QDataStream &in, QDateTime &dt);
+KCALENDARCORE_EXPORT QDateTime deserializeKDateTimeAsQDateTime(QDataStream &in);
 
 void serializeQDateTimeList(QDataStream &out, const QList<QDateTime> &list);
 void deserializeQDateTimeList(QDataStream &in, QList<QDateTime> &list);
